@@ -6,6 +6,7 @@ use WWW::Sitebase -Base;
 use Carp;
 use WWW::Mechanize;
 use File::Spec::Functions;
+use Term::ReadKey; # For password prompt
 
 =head1 NAME
 
@@ -13,11 +14,11 @@ WWW::Sitebase::Navigator - Base class for modules that navigate web sites
 
 =head1 VERSION
 
-Version 0.07
+Version 0.09
 
 =cut
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 =head1 SYNOPSIS
 
@@ -627,7 +628,11 @@ sub _get_acct {
     unless ( defined $prefs{"password"} ) { $prefs{"password"} = "" }
     my $password_indicator = $prefs{'password'} ? '*****' : '';
     print "Password [". $password_indicator . "]: ";
-    $res = <STDIN>; chomp $res;
+    ReadMode 'noecho'; # From Term::ReadKey.  Make password not echo.
+    $res = ReadLine 0;
+    chomp $res;
+    ReadMode 'normal';
+    print "\n"; # Because ReadLine won't output a new line when they hit return
     if ( $res ) {
         $prefs{"password"} = $res;
     }
@@ -635,11 +640,13 @@ sub _get_acct {
     # Make the cache directory if it doesn't exist.
     $self->make_cache_dir;
 
-    # Store the new values.
+    # Store the new values.  We clobber the file, set it r/w by the user,
+    # *then* write.
     open ( PREFS, ">", $cache_filepath ) or croak $!;
+    chmod 0600, $cache_filepath;
     print PREFS "email:" . $prefs{"email"} . "\n" .
         "password:" . $prefs{"password"} . "\n";
-    close PREFS;
+    close PREFS || croak "Error closing file when writing username/password: $!";
     
     # Store the account info.
     $self->{account_name}=$prefs{"email"};
